@@ -8,11 +8,10 @@ from pythonwhat.check_has_context import has_context
 from functools import partial
 
 MSG_MISSING = "Define more `with` statements."
-MSG_PREPEND = "FMT:In your {ordinal} {typestr}, "
-MSG_PREPEND2 = "FMT:Check the {child[part]} of the {ordinal} `with` statement. "
-MSG_NUM_CTXT = "make sure to use the correct number of context variables. It seems you defined too many."
-MSG_NUM_CTXT2 = "make sure to use the correct number of context variables. It seems you defined too little."
-MSG_CTXT_NAMES = "FMT:make sure to use the correct context variable names. Was expecting `{sol_vars}` but got `{stu_vars}`."
+MSG_PREPEND = "FMT:Check the {typestr}. "
+MSG_NUM_CTXT = "Make sure to use the correct number of context variables. It seems you defined too many."
+MSG_NUM_CTXT2 = "Make sure to use the correct number of context variables. It seems you defined too little."
+MSG_CTXT_NAMES = "FMT:Make sure to use the correct context variable names. Was expecting `{sol_vars}` but got `{stu_vars}`."
 
 
 def test_with(index,
@@ -35,10 +34,10 @@ with open_file('...') as file:
 
     """
 
-    check_with = partial(check_node, 'withs', index-1, "`with` statement", MSG_MISSING, state=state)
+    check_with = partial(check_node, 'withs', index-1, "{ordinal} `with` statement", MSG_MISSING, state=state)
 
-    child =  check_with(MSG_PREPEND  if expand_message else "")
-    child2 = check_with(MSG_PREPEND2 if expand_message else "")
+    child =  check_with(MSG_PREPEND if expand_message else "")
+    child2 = check_with(MSG_PREPEND if expand_message else "")
 
     if context_vals:
         # test context var names ----
@@ -51,9 +50,10 @@ with open_file('...') as file:
     # Context sub tests ----
     if context_tests and not isinstance(context_tests, list): context_tests = [context_tests]
 
+    expand_msg = None if expand_message else ""
     for i, context_test in enumerate(context_tests or []):
         # partial the substate check, because the function uses two prepended messages
-        check_context = partial(check_part_index, 'context', i, "%s context"%utils.get_ord(i+1), MSG_NUM_CTXT2)
+        check_context = partial(check_part_index, 'context', i, "%s context"%utils.get_ord(i+1), missing_msg=MSG_NUM_CTXT2, expand_msg=expand_msg)
 
         check_context(state=child)                   # test exist
 
@@ -62,6 +62,6 @@ with open_file('...') as file:
     
     # Body sub tests ----
     if body is not None:
-        body_state = check_part('body', 'body', state=child2)
+        body_state = check_part('body', 'body', expand_msg=expand_msg, state=child2)
 
         with_context(body, state=body_state)
